powered by
qryflow_workflow
qryflow_results() retrieves the query results from a list returned by qryflow_run(), typically one that includes parsed and executed SQL chunks.
qryflow_results()
qryflow_run()
qryflow_results(x, ..., simplify = FALSE)
A named list of query results, or a single result object if simplify = TRUE and only one result is present.
simplify = TRUE
Results from qryflow_run(), usually containing a mixture of qryflow_chunk objects.
qryflow_chunk
Reserved for future use.
Logical; if TRUE, simplifies the result to a single object if only one query chunk is present. Defaults to FALSE.
TRUE
FALSE
qryflow(), qryflow_run()
qryflow()
con <- example_db_connect(mtcars) filepath <- example_sql_path("mtcars.sql") obj <- qryflow_run(con, filepath) results <- qryflow_results(obj) DBI::dbDisconnect(con)
Run the code above in your browser using DataLab