Use this function to register a custom chunk type with qryflow
Details
To avoid manually registering your custom type each session, consider adding
the registration code to your .Rprofile or creating a package that leverages
.onLoad()
Use this function to register a custom chunk type with qryflow
To avoid manually registering your custom type each session, consider adding
the registration code to your .Rprofile or creating a package that leverages
.onLoad()